delu.nn
=======

.. currentmodule:: delu.nn

.. automodule:: delu.nn

.. autosummary::
    :nosignatures:
    :toctree: generated
    :template: class.rst

    Lambda
    NLinear

.. autosummary::
    :nosignatures:
    :toctree: generated
    :template: function.rst

    named_sequential
